@@ -12,6 +12,7 @@ import tornado.ioloop
 from rdlm.lock import LOCK_MANAGER_INSTANCE
 import functools
 
+
 class LocksHandler(RequestHandler):
     """Class which handles the /locks/[resource] URL"""
 
@@ -21,14 +22,16 @@ class LocksHandler(RequestHandler):
         @param name: name of the resource
         @param lock: lock object
         '''
-        tornado.ioloop.IOLoop.instance().add_callback(functools.partial(self.on_active, name, lock))
+        tornado.ioloop.IOLoop.instance().add_callback(functools.partial(self.on_active,
+                                                                        name, lock))
 
     def on_delete_wrapper(self, admin=False):
         '''
-        @summary: wrapper method to invoke on_delete method through tornado ioloop 
+        @summary: wrapper method to invoke on_delete method through tornado ioloop
         @param admin: if True, the delete is made by an admin request
         '''
-        tornado.ioloop.IOLoop.instance().add_callback(functools.partial(self.on_delete, admin=admin))
+        tornado.ioloop.IOLoop.instance().add_callback(functools.partial(self.on_delete,
+                                                                        admin=admin))
 
     def on_active(self, name, lock):
         '''
@@ -36,7 +39,7 @@ class LocksHandler(RequestHandler):
         @param name: name of the resource
         @param lock: lock object
 
-        The method returns an HTTP/201 in this case with 
+        The method returns an HTTP/201 in this case with
         the corresponding Location header
         '''
         url = "%s%s" % (self.get_base_url(self.request), self.reverse_url("lock", name, lock.uid))
@@ -46,7 +49,7 @@ class LocksHandler(RequestHandler):
         '''
         @summary: method called when the wait for the lock is over
         @param admin: True if the delete is made by an admin request
-        
+
         The method returns an HTTP/408 or an HTTP/409 in this case
         (depending if the delete is made by an admin request)
         '''
@@ -56,9 +59,9 @@ class LocksHandler(RequestHandler):
             self.send_error(status_code=408, message="lock request (wait) timeout")
 
     @tornado.web.asynchronous
-    def post(self, name): # pylint: disable-msg=W0221
+    def post(self, name):
         '''
-        @summary: deals with POST request (acquiring locks on resource) 
+        @summary: deals with POST request (acquiring locks on resource)
         @param name: name of the resource
         '''
         raw_body = self.request.body.decode('utf-8')
@@ -69,7 +72,6 @@ class LocksHandler(RequestHandler):
         if not(lock):
             self.send_error(status_code=400, message="invalid json body")
             return
-        lock.set_callbacks(functools.partial(self.on_active_wrapper, name, lock), self.on_delete_wrapper)
+        lock.set_callbacks(functools.partial(self.on_active_wrapper, name, lock),
+                           self.on_delete_wrapper)
         LOCK_MANAGER_INSTANCE.add_lock(name, lock)
-            
-        
