@@ -7,6 +7,7 @@ from rdlm.main import get_ioloop as rdlm_get_ioloop
 import json
 import tornado.ioloop
 import tornado.gen
+import time
 
 TEST_MULTIPLE_WAITERS1 = 0
 TEST_MULTIPLE_WAITERS2 = 0
@@ -14,16 +15,20 @@ TEST_MULTIPLE_WAITERS2 = 0
 class LockTestCase(tornado.testing.AsyncHTTPTestCase):
 
     def get_app(self):
-        return rdlm_get_app(unit_testing=True)
+        return rdlm_get_app()
+
+    # compatibility with python 2.6
+    def assertIn(self, str1, str2):
+        self.assertTrue(str1 in str2)
 
     def get_new_ioloop(self): 
         return rdlm_get_ioloop()
 
     def tearDown(self):
-        req = tornado.httpclient.HTTPRequest(self.get_url("/reset"))
+        req = tornado.httpclient.HTTPRequest(self.get_url("/resources"), method='DELETE')
         self.http_client.fetch(req, self.stop)
         response = self.wait()
-        self.assertEqual(response.code, 200)
+        self.assertEqual(response.code, 204)
         super(LockTestCase, self).tearDown()
 
     def test_not_acquired_lock_bad_json(self):
@@ -101,8 +106,8 @@ class LockTestCase(tornado.testing.AsyncHTTPTestCase):
         self.http_client.fetch(req, self.stop)
         response = self.wait()
         self.assertEqual(response.code, 200)
-        self.assertEqual(response.headers['Content-Type'], 'application/json')
-        tmp = json.loads(response.body)
+        self.assertEqual(response.headers['Content-Type'], 'application/hal+json')
+        tmp = json.loads(response.body.decode('utf-8'))
         self.assertEqual(tmp['title'], "test case")
         self.assertEqual(tmp['wait'], 5)
         self.assertEqual(tmp['lifetime'], 60)
@@ -140,33 +145,36 @@ class LockTestCase(tornado.testing.AsyncHTTPTestCase):
         self.assertEqual(response.code, 408)
 
     def _test_multiple_waiters_callback2(self, r):
-        self.assertEqual(r.code, 204)
-
-    def _test_multiple_waiters_callback1(self, r):
         global TEST_MULTIPLE_WAITERS1 # pylint: disable-msg=W0603
         TEST_MULTIPLE_WAITERS1 = TEST_MULTIPLE_WAITERS1 + 1
-        self.assertEqual(r.code, 201)
-        lock_url = r.headers['Location']
-        req = tornado.httpclient.HTTPRequest(lock_url, method='DELETE')
-        self.http_client.fetch(req, callback=self._test_multiple_waiters_callback2)
+        self.assertEqual(r.code, 204)
         if TEST_MULTIPLE_WAITERS1 == 4:
             self.stop()
 
-    def _test_multiple_waiters_callback3(self, r):
+    def _test_multiple_waiters_callback4(self, r):
         global TEST_MULTIPLE_WAITERS2 # pylint: disable-msg=W0603
         TEST_MULTIPLE_WAITERS2 = TEST_MULTIPLE_WAITERS2 + 1
+        self.assertEqual(r.code, 204)
+        if TEST_MULTIPLE_WAITERS2 == 4:
+            self.stop()
+
+    def _test_multiple_waiters_callback1(self, r):
         self.assertEqual(r.code, 201)
         lock_url = r.headers['Location']
         req = tornado.httpclient.HTTPRequest(lock_url, method='DELETE')
         self.http_client.fetch(req, callback=self._test_multiple_waiters_callback2)
-        if TEST_MULTIPLE_WAITERS2 == 4:
-            self.stop()
+
+    def _test_multiple_waiters_callback3(self, r):
+        self.assertEqual(r.code, 201)
+        lock_url = r.headers['Location']
+        req = tornado.httpclient.HTTPRequest(lock_url, method='DELETE')
+        self.http_client.fetch(req, callback=self._test_multiple_waiters_callback4)
 
     def test_multiple_waiters1(self):
-        self._acquire_lock("resource1", 10, 60, "test case", callback=self._test_multiple_waiters_callback1)
-        self._acquire_lock("resource2", 10, 60, "test case", callback=self._test_multiple_waiters_callback1)
-        self._acquire_lock("resource3", 10, 60, "test case", callback=self._test_multiple_waiters_callback1)
-        self._acquire_lock("resource4", 10, 60, "test case", callback=self._test_multiple_waiters_callback1)
+        self._acquire_lock("resource10", 10, 60, "test case", callback=self._test_multiple_waiters_callback1)
+        self._acquire_lock("resource20", 10, 60, "test case", callback=self._test_multiple_waiters_callback1)
+        self._acquire_lock("resource30", 10, 60, "test case", callback=self._test_multiple_waiters_callback1)
+        self._acquire_lock("resource40", 10, 60, "test case", callback=self._test_multiple_waiters_callback1)
         self.wait()
 
     def test_multiple_waiters2(self):
@@ -176,6 +184,76 @@ class LockTestCase(tornado.testing.AsyncHTTPTestCase):
         self._acquire_lock("resource1", 10, 60, "test case", callback=self._test_multiple_waiters_callback3)
         self.wait()
 
+    def _test_delete_all_callback1(self, r):
+        self.assertEqual(r.code, 409)
+        self.stop()
+
+    def _test_delete_all_callback2(self):
+        req = tornado.httpclient.HTTPRequest(self.get_url("/resources"), method='DELETE')
+        self.http_client.fetch(req, self._test_delete_all_callback3)
+
+    def _test_delete_all_callback3(self, response):
+        self.assertEqual(response.code, 204)
+        self.stop()
+        
+    def test_delete_all(self):
+        location1 = self._acquire_lock("resource1", 5, 60, "test case")
+        location3 = self._acquire_lock("resource2", 5, 60, "test case")
+        self._acquire_lock("resource1", 5, 60, "test case", callback=self._test_delete_all_callback1)       
+        tornado.ioloop.IOLoop.instance().add_timeout(time.time() + 2, self._test_delete_all_callback2)
+        self.wait()
+        self.wait()
+        for location in [location1, location3]:
+            req2 = tornado.httpclient.HTTPRequest(location, method='GET')
+            self.http_client.fetch(req2, self.stop)
+            response2 = self.wait()
+            self.assertEqual(response2.code, 404)
+
+    def test_delete_resource(self):
+        location1 = self._acquire_lock("resource1", 5, 60, "test case")
+        req = tornado.httpclient.HTTPRequest(self.get_url("/resources/resource2"), method='DELETE')
+        self.http_client.fetch(req, self.stop)
+        r = self.wait()
+        self.assertEqual(r.code, 404)
+        req2 = tornado.httpclient.HTTPRequest(location1, method='GET')
+        self.http_client.fetch(req2, self.stop)
+        response2 = self.wait()
+        self.assertEqual(response2.code, 200)
+        req = tornado.httpclient.HTTPRequest(self.get_url("/resources/resource1"), method='DELETE')
+        self.http_client.fetch(req, self.stop)
+        r = self.wait()
+        self.assertEqual(r.code, 204)
+        req2 = tornado.httpclient.HTTPRequest(location1, method='GET')
+        self.http_client.fetch(req2, self.stop)
+        response2 = self.wait()
+        self.assertEqual(response2.code, 404)
+
+    def test_get_resource(self):
+        self._acquire_lock("resource1", 5, 60, "test case")
+        req = tornado.httpclient.HTTPRequest(self.get_url("/resources/resource2"), method='GET')
+        self.http_client.fetch(req, self.stop)
+        r = self.wait()
+        self.assertEqual(r.code, 200)
+        req = tornado.httpclient.HTTPRequest(self.get_url("/resources/resource1"), method='GET')
+        self.http_client.fetch(req, self.stop)
+        r = self.wait()
+        self.assertEqual(r.code, 200)
+
+    def test_get_resources(self):
+        self._acquire_lock("resource1", 5, 60, "test case")
+        self._acquire_lock("resource2", 5, 60, "test case")
+        req = tornado.httpclient.HTTPRequest(self.get_url("/resources"), method='GET')
+        self.http_client.fetch(req, self.stop)
+        r = self.wait()
+        self.assertEqual(r.code, 200)
+
+
+
+
+
+
+    
+
         
         
 
@@ -185,4 +263,4 @@ class LockTestCase(tornado.testing.AsyncHTTPTestCase):
 
 
 
-    
\ No newline at end of file
+    
